@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.c,v 1.32 2005/01/14 04:23:05 adamh Exp $
+ *  $Id: ephy-embed-single.c,v 1.35 2005/04/08 17:02:52 chpe Exp $
  */
 
 #include "config.h"
@@ -23,6 +23,7 @@
 #include "ephy-embed-single.h"
 #include "ephy-embed-type-builtins.h"
 #include "ephy-marshal.h"
+#include "ephy-signal-accumulator.h"
 
 static void ephy_embed_single_iface_init (gpointer g_class);
 
@@ -56,6 +57,28 @@ ephy_embed_single_iface_init (gpointer g_class)
 
 	if (initialised == FALSE)
 	{
+/**
+ * EphyEmbedSingle::new-window:
+ * @single:
+ * @parent_embed: the #EphyEmbed requesting the new window, or %NULL
+ * @mask: a #EphyEmbedChrome
+ *
+ * The ::new_window signal is emitted when a new window needs to be opened.
+ * For example, when a JavaScript popup window was opened.
+ *
+ * Return a new #EphyEmbed.
+ **/
+	g_signal_new ("new-window",
+		      EPHY_TYPE_EMBED_SINGLE,
+		      G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (EphyEmbedSingleIface, new_window),
+		      ephy_signal_accumulator_object, ephy_embed_get_type,
+		      ephy_marshal_OBJECT__OBJECT_FLAGS,
+		      GTK_TYPE_WIDGET,
+		      2,
+		      GTK_TYPE_WIDGET,
+		      EPHY_TYPE_EMBED_CHROME);
+
 /**
  * EphyEmbedSingle::handle_content:
  * @single:
@@ -114,8 +137,30 @@ ephy_embed_single_iface_init (gpointer g_class)
 		      ephy_marshal_BOOLEAN__STRING_STRING,
 		      G_TYPE_BOOLEAN,
 		      2,
-		      G_TYPE_STRING,
-		      G_TYPE_STRING);
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
+
+/**
+ * EphyEmbedSingle::add-search-engine
+ * @single:
+ * @url: The url of the search engine definition file
+ * @icon_url: The url of the icon to use for this engine
+ * @title: The title of the search engine to be added
+ *
+ * The ::add-search-engine signal is emitted when the user clicks a javascript link that
+ * requests adding a search engine to the sidebar.
+ **/
+	g_signal_new ("add-search-engine",
+		      EPHY_TYPE_EMBED_SINGLE,
+		      G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (EphyEmbedSingleIface, add_search_engine),
+		      g_signal_accumulator_true_handled, NULL,
+		      ephy_marshal_BOOLEAN__STRING_STRING_STRING,
+		      G_TYPE_BOOLEAN,
+		      3,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 /**
  * EphyEmbedSingle::check_content:
