@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.27.2.2 2005/05/30 17:01:08 chpe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.30 2005/05/30 16:59:37 chpe Exp $
  */
 
 /*
@@ -45,6 +45,7 @@
 #include <nsICRLInfo.h>
 #include <nsISimpleEnumerator.h>
 #include <nsIArray.h>
+#include <nsIDOMWindow.h>
 #undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
 #define MOZILLA_INTERNAL_API 1
@@ -528,7 +529,7 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 				    PRBool *_retval)
 {
 	GtkWidget *dialog, *label, *content_vbox, *vbox;
-	GtkWidget *check_ssl, *check_software;
+	GtkWidget *check_ssl;
 	char *msg, *tertiary;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
@@ -579,11 +580,6 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_ssl), TRUE);
 	gtk_box_pack_start (GTK_BOX(vbox), check_ssl, TRUE, TRUE, 0);
 
-	check_software = gtk_check_button_new_with_mnemonic 
-				  (_("_Software developers"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_software), FALSE);
-	gtk_box_pack_start (GTK_BOX(vbox), check_software, TRUE, TRUE, 0);
-
 	gtk_box_pack_start (GTK_BOX (content_vbox), higgy_indent_widget (vbox), 
 			    FALSE, FALSE, 0);
 
@@ -614,10 +610,6 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 			*_trust |= nsIX509CertDB::TRUSTED_SSL;
 		}
 
-		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_software)))
-		{
-			*_trust |= nsIX509CertDB::TRUSTED_OBJSIGN;
-		}
 		*_retval = PR_TRUE;
 	}
 	gtk_widget_destroy (dialog);
