@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.65 2005/02/28 22:07:57 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.71 2005/05/25 22:08:01 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -56,18 +56,27 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
 
+#include <nsIIOService.h>
+#include <nsIURI.h>
+#include <nsIDOMDocument.h>
+#include <nsILocalFile.h>
+#include <nsIWebBrowserPersist.h>
+#include <nsIObserver.h>
+#include <nsIRequest.h>
 #include <nsIFileURL.h>
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include <nsMemory.h>
+#include <nsNetError.h>
 
-#include <errno.h>
 #include <stdlib.h>
 
 const char* const persistContractID = "@mozilla.org/embedding/browser/nsWebBrowserPersist;1";
 
 MozDownload::MozDownload() :
+	mTotalProgress(-1),
+	mCurrentProgress(0),
 	mMaxSize(-1),
 	mStatus(NS_OK),
 	mEmbedPersist(nsnull),
@@ -83,26 +92,53 @@ MozDownload::~MozDownload()
 	NS_ASSERTION (!mEphyDownload, "MozillaDownload still alive!");
 }
 
-#ifdef HAVE_NSITRANSFER_H
-NS_IMPL_ISUPPORTS2(MozDownload, nsIWebProgressListener, nsITransfer)
+#ifdef HAVE_GECKO_1_8
+NS_IMPL_ISUPPORTS3(MozDownload, nsIWebProgressListener, nsIWebProgressListener2, nsITransfer)
 #else
 NS_IMPL_ISUPPORTS3(MozDownload, nsIWebProgressListener, nsIDownload, nsITransfer)
 #endif
 
-NS_IMETHODIMP
+#ifdef HAVE_GECKO_1_8
+nsresult
+MozDownload::InitForEmbed (nsIURI *aSource, nsIURI *aTarget, const nsAString &aDisplayName,
+		           nsIMIMEInfo *aMIMEInfo, PRTime aStartTime, nsICancelable *aCancelable,
+		           MozillaEmbedPersist *aEmbedPersist, PRInt64 aMaxSize)
+{
+	mEmbedPersist = aEmbedPersist;
+	mMaxSize = aMaxSize;
+	return Init (aSource, aTarget, aDisplayName, aMIMEInfo, aStartTime, aCancelable);
+}
+#else
+nsresult
 MozDownload::InitForEmbed (nsIURI *aSource, nsIURI *aTarget, const PRUnichar *aDisplayName,
 		           nsIMIMEInfo *aMIMEInfo, PRInt64 startTime, nsIWebBrowserPersist *aPersist,
-		           MozillaEmbedPersist *aEmbedPersist, PRInt32 aMaxSize)
+		           MozillaEmbedPersist *aEmbedPersist, PRInt64 aMaxSize)
 {
 	mEmbedPersist = aEmbedPersist;
 	mMaxSize = aMaxSize;
 	return Init (aSource, aTarget, aDisplayName, aMIMEInfo, startTime, aPersist);
 }
+#endif
 
+#ifdef HAVE_GECKO_1_8
+/* void init (in nsIURI aSource, in nsIURI aTarget, in AString aDisplayName, in nsIMIMEInfo aMIMEInfo, in PRTime startTime, in nsICancelable aCancelable); */
+NS_IMETHODIMP
+MozDownload::Init (nsIURI *aSource,
+		   nsIURI *aTarget,
+		   const nsAString &aDisplayName,
+		   nsIMIMEInfo *aMIMEInfo,
+		   PRTime aStartTime,
+		   nsICancelable *aCancelable)
+#else
 /* void init (in nsIURI aSource, in nsIURI aTarget, in wstring aDisplayName, in nsIMIMEInfo aMIMEInfo, in long long startTime, in nsIWebBrowserPersist aPersist); */
 NS_IMETHODIMP
-MozDownload::Init(nsIURI *aSource, nsIURI *aTarget, const PRUnichar *aDisplayName,
-		  nsIMIMEInfo *aMIMEInfo, PRInt64 startTime, nsIWebBrowserPersist *aPersist)
+MozDownload::Init (nsIURI *aSource,
+		   nsIURI *aTarget,
+		   const PRUnichar *aDisplayName,
+		   nsIMIMEInfo *aMIMEInfo,
+		   PRInt64 aStartTime,
+		   nsIWebBrowserPersist *aPersist)
+#endif
 {
 	PRBool addToView = PR_TRUE;
 
@@ -117,7 +153,7 @@ MozDownload::Init(nsIURI *aSource, nsIURI *aTarget, const PRUnichar *aDisplayNam
 
 	mSource = aSource;
 	mDestination = aTarget;
-	mStartTime = startTime;
+	mStartTime = aStartTime;
 	mTotalProgress = 0;
 	mCurrentProgress = 0;
 	mPercentComplete = 0;
@@ -125,11 +161,16 @@ MozDownload::Init(nsIURI *aSource, nsIURI *aTarget, const PRUnichar *aDisplayNam
 	mLastUpdate = mStartTime;
 	mMIMEInfo = aMIMEInfo;
 
+#ifdef HAVE_GECKO_1_8
+	/* This will create a refcount cycle, which needs to be broken in ::OnStateChange */
+	mCancelable = aCancelable;
+#else
 	if (aPersist)
 	{
 		mWebPersist = aPersist;
 		aPersist->SetProgressListener(this);
         }
+#endif
 
 	if (addToView)
 	{ 
@@ -159,7 +200,7 @@ MozDownload::GetSource(nsIURI **aSource)
 	return NS_OK;
 }
 
-#ifndef HAVE_NSITRANSFER_H
+#ifndef HAVE_GECKO_1_8
 NS_IMETHODIMP
 MozDownload::GetTarget(nsIURI **aTarget)
 {
@@ -185,7 +226,7 @@ MozDownload::GetTargetFile (nsILocalFile** aTargetFile)
 	return rv;
 }
 
-#ifndef HAVE_NSITRANSFER_H
+#ifndef HAVE_GECKO_1_8
 NS_IMETHODIMP
 MozDownload::GetPersist(nsIWebBrowserPersist **aPersist)
 {
@@ -205,24 +246,7 @@ MozDownload::GetPercentComplete(PRInt32 *aPercentComplete)
  	return NS_OK;
 }
 
-#ifndef HAVE_NSITRANSFER_H
-#ifdef MOZ_NSIDOWNLOAD_GETSIZE
-/* readonly attribute PRUint64 amountTransferred; */
-NS_IMETHODIMP
-MozDownload::GetAmountTransferred(PRUint64 *aAmountTransferred)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
-
-/* readonly attribute PRUint64 size; */
-NS_IMETHODIMP
-MozDownload::GetSize(PRUint64 *aSize)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
-
-#endif  /* MOZ_NSIDOWNLOAD_GETSIZE */
-
+#ifndef HAVE_GECKO_1_8
 NS_IMETHODIMP
 MozDownload::GetStartTime(PRInt64 *aStartTime)
 {
@@ -243,10 +267,10 @@ MozDownload::SetDisplayName(const PRUnichar * aDisplayName)
 {
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
-#endif /* !HAVE_NSITRANSFER_H */
+#endif /* !HAVE_GECKO_1_8 */
 
 NS_IMETHODIMP
-MozDownload::GetTotalProgress(PRInt32 *aTotalProgress)
+MozDownload::GetTotalProgress(PRInt64 *aTotalProgress)
 {
 	NS_ENSURE_ARG_POINTER(aTotalProgress);
 	*aTotalProgress = mTotalProgress;
@@ -255,7 +279,7 @@ MozDownload::GetTotalProgress(PRInt32 *aTotalProgress)
 }
 
 NS_IMETHODIMP
-MozDownload::GetCurrentProgress(PRInt32 *aCurrentProgress)
+MozDownload::GetCurrentProgress(PRInt64 *aCurrentProgress)
 {
 	NS_ENSURE_ARG_POINTER(aCurrentProgress);
 	*aCurrentProgress = mCurrentProgress;
@@ -290,6 +314,7 @@ MozDownload::GetMIMEInfo(nsIMIMEInfo **aMIMEInfo)
 	return NS_OK;
 }
 
+#ifndef HAVE_GECKO_1_8
 NS_IMETHODIMP
 MozDownload::GetListener(nsIWebProgressListener **aListener)
 {
@@ -307,7 +332,10 @@ MozDownload::SetListener(nsIWebProgressListener *aListener)
 NS_IMETHODIMP
 MozDownload::GetObserver(nsIObserver **aObserver)
 {
-	return NS_ERROR_NOT_IMPLEMENTED;
+	*aObserver = mObserver;
+	NS_IF_ADDREF (*aObserver);
+
+	return NS_OK;
 }
 
 NS_IMETHODIMP
@@ -317,6 +345,7 @@ MozDownload::SetObserver(nsIObserver *aObserver)
 
 	return NS_OK;
 }
+#endif
 
 NS_IMETHODIMP 
 MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
@@ -327,7 +356,7 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 	if (NS_FAILED(aStatus) && NS_SUCCEEDED(mStatus))
         	mStatus = aStatus;
 
-	if (aStateFlags & EPHY_EMBED_STATE_START)
+	if (aStateFlags & STATE_START)
 	{
 		mDownloadState = EPHY_DOWNLOAD_DOWNLOADING;
 
@@ -338,7 +367,7 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 	}
 
 	/* We will get this even in the event of a cancel */
-	if (aStateFlags & EPHY_EMBED_STATE_STOP)
+	if (aStateFlags & STATE_STOP)
 	{
 		/* Keep us alive */
 		nsCOMPtr<nsITransfer> kungFuDeathGrip(this);
@@ -349,11 +378,16 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 			g_signal_emit_by_name (mEphyDownload, "changed");
 		}
 
+#ifdef HAVE_GECKO_1_8
+		/* break refcount cycle */
+		mCancelable = nsnull;
+#else
 	        if (mWebPersist)
 		{
 	            mWebPersist->SetProgressListener(nsnull);
 	            mWebPersist = nsnull;
 	        }
+#endif
 
 		if (mEmbedPersist)
 		{
@@ -370,7 +404,7 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 		{
 			GnomeVFSMimeApplication *helperApp;
 			nsEmbedCString mimeType;
-#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
+#ifdef HAVE_GECKO_1_8
 			rv = mMIMEInfo->GetMIMEType (mimeType);
 			NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -403,11 +437,11 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 
 			/* HACK we use the application description to decide
 			   if we have to open the saved file */
-			if (g_str_has_suffix (cDesc.get(), "gnome-default:"))
+			if (g_str_has_prefix (cDesc.get(), "gnome-default:"))
 			{
 				/* Format gnome-default:<usertime>:<helperapp id> */
 				char **str = g_strsplit (cDesc.get(), ":", -1);
-				g_return_val_if_fail (g_strv_length (str) != 3, NS_ERROR_FAILURE);
+				g_return_val_if_fail (g_strv_length (str) == 3, NS_ERROR_FAILURE);
 
 				char *end;
 				guint32 user_time = strtoul (str[1], &end, 0);
@@ -430,10 +464,38 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 	return NS_OK; 
 }
 
-NS_IMETHODIMP 
-MozDownload::OnProgressChange(nsIWebProgress *aWebProgress, nsIRequest *aRequest,
-			      PRInt32 aCurSelfProgress, PRInt32 aMaxSelfProgress,
-			      PRInt32 aCurTotalProgress, PRInt32 aMaxTotalProgress)
+#ifdef HAVE_GECKO_1_8
+NS_IMETHODIMP
+MozDownload::OnProgressChange (nsIWebProgress *aWebProgress,
+			       nsIRequest *aRequest,
+			       PRInt32 aCurSelfProgress,
+			       PRInt32 aMaxSelfProgress,
+			       PRInt32 aCurTotalProgress,
+			       PRInt32 aMaxTotalProgress)
+{
+	return OnProgressChange64 (aWebProgress, aRequest,
+				   aCurSelfProgress, aMaxSelfProgress,
+				   aCurTotalProgress, aMaxTotalProgress);
+}
+
+/* void onProgressChange64 (in nsIWebProgress aWebProgress, in nsIRequest aRequest, in long long aCurSelfProgress, in long long aMaxSelfProgress, in long long aCurTotalProgress,
+ in long long aMaxTotalProgress); */
+NS_IMETHODIMP
+MozDownload::OnProgressChange64 (nsIWebProgress *aWebProgress,
+				 nsIRequest *aRequest,
+				 PRInt64 aCurSelfProgress,
+				 PRInt64 aMaxSelfProgress,
+				 PRInt64 aCurTotalProgress,
+				 PRInt64 aMaxTotalProgress)
+#else /* !HAVE_GECKO_1_8 */
+NS_IMETHODIMP
+MozDownload::OnProgressChange (nsIWebProgress *aWebProgress,
+			       nsIRequest *aRequest,
+			       PRInt32 aCurSelfProgress,
+			       PRInt32 aMaxSelfProgress,
+			       PRInt32 aCurTotalProgress,
+			       PRInt32 aMaxTotalProgress)
+#endif /* HAVE_GECKO_1_8 */
 {
 	if (mMaxSize >= 0 &&
 	    ((aMaxTotalProgress > 0 && mMaxSize < aMaxTotalProgress) ||
@@ -501,7 +563,14 @@ MozDownload::Cancel()
 	{
 		return;
 	}
-	
+
+#ifdef HAVE_GECKO_1_8
+	if (mCancelable)
+	{
+		/* FIXME: error code? */
+		mCancelable->Cancel (NS_BINDING_ABORTED);
+	}
+#else
 	if (mWebPersist)
 	{
 		mWebPersist->CancelSave ();
@@ -510,7 +579,8 @@ MozDownload::Cancel()
 	if (mObserver)
 	{
 		mObserver->Observe (nsnull, "oncancel", nsnull);
-	}	
+	}
+#endif
 }
 
 void
@@ -537,7 +607,7 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 				  nsILocalFile* inDestFile, const char *contentType,
 				  nsIURI* inOriginalURI, MozillaEmbedPersist *embedPersist,
 				  nsIInputStream *postData, nsISupports *aCacheKey,
-				  PRInt32 aMaxSize)
+				  PRInt64 aMaxSize)
 {
 	nsresult rv = NS_OK;
 
@@ -549,7 +619,7 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 			 strcmp (contentType, "text/xml") == 0 ||
 			 strcmp (contentType, "application/xhtml+xml") == 0));
 
-	nsCOMPtr<nsIWebBrowserPersist> webPersist = do_CreateInstance(persistContractID, &rv);
+	nsCOMPtr<nsIWebBrowserPersist> webPersist (do_CreateInstance(persistContractID, &rv));
 	NS_ENSURE_SUCCESS (rv, rv);
   
 	PRInt64 timeNow = PR_Now();
@@ -566,8 +636,17 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 
 	MozDownload *downloader = new MozDownload ();
 	/* dlListener attaches to its progress dialog here, which gains ownership */
+	/* FIXME is that still true? */
+#ifdef HAVE_GECKO_1_8
+	rv = downloader->InitForEmbed (inOriginalURI, destURI, fileDisplayName,
+				       nsnull, timeNow, webPersist, embedPersist, aMaxSize);
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	rv = webPersist->SetProgressListener (downloader);
+#else
 	rv = downloader->InitForEmbed (inOriginalURI, destURI, fileDisplayName.get(),
 				       nsnull, timeNow, webPersist, embedPersist, aMaxSize);
+#endif
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	PRInt32 flags = nsIWebBrowserPersist::PERSIST_FLAGS_REPLACE_EXISTING_FILES;
