@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.56 2005/01/08 19:41:46 chpe Exp $
+ *  $Id: ephy-node-view.c,v 1.60 2005/04/19 11:14:41 chpe Exp $
  */
 
 #include "config.h"
@@ -69,8 +69,6 @@ struct _EphyNodeViewPrivate
 	gboolean remove_if_cancelled;
 	int editable_property;
 
-	int searchable_data_column;
-
 	gboolean drag_started;
 	int drag_button;
 	int drag_x;
@@ -445,7 +443,7 @@ drag_drop_cb (GtkWidget *widget,
 
 void
 ephy_node_view_enable_drag_dest (EphyNodeView *view,
-				 GtkTargetEntry *types,
+				 const GtkTargetEntry *types,
 				 int n_types)
 {
 	GtkWidget *treeview;
@@ -567,9 +565,7 @@ ephy_node_view_key_press_cb (GtkTreeView *treeview,
 			     GdkEventKey *event,
 			     EphyNodeView *view)
 {
-	guint32 unicode;
-
-	unicode = gdk_keyval_to_unicode (event->keyval);
+	gboolean handled = FALSE;
 
 	if (event->keyval == GDK_space ||
 	    event->keyval == GDK_Return ||
@@ -582,15 +578,11 @@ ephy_node_view_key_press_cb (GtkTreeView *treeview,
 			selection = gtk_tree_view_get_selection (treeview);
 			gtk_tree_selection_selected_foreach
 					(selection, path_toggled, view);
+			handled = TRUE;
 		}
 	}
-	else if (view->priv->searchable_data_column != -1 && unicode)
-	{
-		return ephy_gui_select_row_by_key
-			(treeview, view->priv->searchable_data_column, unicode);
-	}
 
-	return FALSE;
+	return handled;
 }
 
 static void
@@ -738,7 +730,7 @@ motion_notify_cb (GtkWidget *widget,
 		{
 			context = gtk_drag_begin
 				(widget, view->priv->source_target_list,
-                                 GDK_ACTION_COPY,
+                                 GDK_ACTION_ASK | GDK_ACTION_COPY | GDK_ACTION_LINK,
                                  view->priv->drag_button,
                                  (GdkEvent*)event);
 
@@ -1158,13 +1150,14 @@ ephy_node_view_add_data_column (EphyNodeView *view,
 	return column;
 }
 
-GtkTreeViewColumn *
+int
 ephy_node_view_add_column (EphyNodeView *view,
 			   const char  *title,
 			   GType value_type,
 			   guint prop_id,
 			   EphyNodeViewFlags flags,
-			   EphyTreeModelNodeValueFunc icon_func)
+			   EphyTreeModelNodeValueFunc icon_func,
+			   GtkTreeViewColumn **ret)
 
 {
 	GtkTreeViewColumn *gcolumn;
@@ -1204,12 +1197,6 @@ ephy_node_view_add_column (EphyNodeView *view,
 				  G_CALLBACK (renderer_editing_canceled_cb), view);
 	}
 
-	if ((flags & EPHY_NODE_VIEW_SEARCHABLE) &&
-	    (view->priv->searchable_data_column == -1))
-	{
-		view->priv->searchable_data_column = column;
-	}
-
 	gtk_tree_view_column_pack_start (gcolumn, renderer, TRUE);
 	gtk_tree_view_column_set_attributes (gcolumn, renderer,
 					     "text", column,
@@ -1236,7 +1223,16 @@ ephy_node_view_add_column (EphyNodeView *view,
 		gtk_tree_view_column_set_sort_column_id (gcolumn, column);
 	}
 
-	return gcolumn;
+	if (flags & EPHY_NODE_VIEW_SEARCHABLE)
+	{
+		gtk_tree_view_set_search_column (GTK_TREE_VIEW (view), column);
+		gtk_tree_view_set_enable_search (GTK_TREE_VIEW (view), TRUE);
+	}
+
+	if (ret != NULL)
+		*ret = gcolumn;
+
+	return column;
 }
 
 void
@@ -1279,7 +1275,6 @@ ephy_node_view_init (EphyNodeView *view)
 	view->priv = EPHY_NODE_VIEW_GET_PRIVATE (view);
 
 	view->priv->toggle_column = -1;
-	view->priv->searchable_data_column = -1;
 	view->priv->priority_column = -1;
 	view->priv->priority_prop_id = 0;
 	view->priv->sort_column = -1;
@@ -1407,9 +1402,10 @@ ephy_node_view_select_node (EphyNodeView *view,
 
 void
 ephy_node_view_enable_drag_source (EphyNodeView *view,
-				   GtkTargetEntry *types,
+				   const GtkTargetEntry *types,
 				   int n_types,
-				   int column)
+				   int base_drag_column,
+				   int extra_drag_column)
 {
 	GtkWidget *treeview;
 
@@ -1420,8 +1416,10 @@ ephy_node_view_enable_drag_source (EphyNodeView *view,
 	view->priv->source_target_list =
 		gtk_target_list_new (types, n_types);
 
-	ephy_tree_model_sort_set_column_id (EPHY_TREE_MODEL_SORT (view->priv->sortmodel),
-					    column);
+	ephy_tree_model_sort_set_base_drag_column_id  (EPHY_TREE_MODEL_SORT (view->priv->sortmodel),
+					               base_drag_column);
+	ephy_tree_model_sort_set_extra_drag_column_id (EPHY_TREE_MODEL_SORT (view->priv->sortmodel),
+					               extra_drag_column);
 
 	g_signal_connect_object (G_OBJECT (view),
 			         "button_release_event",
