@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.103.2.1 2005/07/24 12:20:02 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.105 2005/04/24 12:39:12 chpe Exp $
  */
 
 #include "config.h"
@@ -309,6 +309,17 @@ ephy_bookmarks_class_init (EphyBookmarksClass *klass)
 	g_type_class_add_private (object_class, sizeof(EphyBookmarksPrivate));
 }
 
+static gboolean
+save_filter (EphyNode *node,
+	     EphyBookmarks *bookmarks)
+{
+	EphyBookmarksPrivate *priv = bookmarks->priv;
+
+	return node != priv->bookmarks &&
+	       node != priv->favorites &&
+	       node != priv->notcategorized;
+}
+
 static void
 ephy_bookmarks_save (EphyBookmarks *eb)
 {
@@ -321,10 +332,8 @@ ephy_bookmarks_save (EphyBookmarks *eb)
 		 (xmlChar *) EPHY_BOOKMARKS_XML_ROOT,
 		 (xmlChar *) EPHY_BOOKMARKS_XML_VERSION,
 		 (xmlChar *) "Do not rely on this file, it's only for internal use. Use bookmarks.rdf instead.",
-		 eb->priv->keywords,
-		 3, eb->priv->bookmarks, eb->priv->favorites, eb->priv->notcategorized,
-		 eb->priv->bookmarks,
-		 0,
+		 eb->priv->keywords, (EphyNodeFilterFunc) save_filter, eb,
+		 eb->priv->bookmarks, NULL, NULL,
 		 NULL);
 
 	/* Export bookmarks in rdf */
@@ -540,7 +549,7 @@ redirect_cb (EphyHistory *history,
 				/* translators: the %s is the title of the bookmark */
 				_("Update bookmark \"%s\"?"),
 				title);
-	gtk_message_dialog_format_secondary_text
+	gtk_message_dialog_format_secondary_markup
 		(GTK_MESSAGE_DIALOG (dialog),
 		/* translators: the %s is a URL */
 		_("The bookmarked page has moved to \"%s\"."),
@@ -1229,11 +1238,13 @@ ephy_bookmarks_solve_smart_url (EphyBookmarks *eb,
 	escaped_arg = gnome_vfs_escape_string (arg);
 
 	t1 = smarturl_only;
-	t2 = strstr (t1, "%s");
-	g_return_val_if_fail (t2 != NULL, NULL);
-	g_string_append_len (s, t1, t2 - t1);
-	g_string_append (s, escaped_arg);
-	t1 = t2 + 2;
+	while ((t2 = strstr (t1, "%s")) != NULL)
+	{
+		g_string_append_len (s, t1, t2 - t1);
+		g_string_append (s, escaped_arg);
+		t1 = t2 + 2;
+	}
+
 	g_string_append (s, t1);
 	ret = g_string_free (s, FALSE);
 
