@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.68 2005/01/15 20:30:49 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.69 2005/01/28 22:25:02 chpe Exp $
  */
 
 #include "config.h"
@@ -885,7 +885,7 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
 	GtkWidget *button;
 
-	LOG ("connect_proxy action %p, proxy %p", action, proxy)
+	LOG ("connect_proxy action %p, proxy %p", action, proxy);
 
 	(* GTK_ACTION_CLASS (parent_class)->connect_proxy) (action, proxy);
 
