@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: ephy-extensions-manager.c,v 1.25 2005/05/21 13:58:23 chpe Exp $
  */
 
 #include "config.h"
@@ -31,7 +31,6 @@
 #include "ephy-shell.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-file-helpers.h"
-#include "ephy-object-helpers.h"
 #include "ephy-debug.h"
 
 #include <libxml/tree.h>
@@ -53,6 +52,11 @@
 #include <libxml/xmlschemas.h>
 #endif
 
+#ifdef ENABLE_PYTHON
+#include "ephy-python-extension.h"
+#include "ephy-python-loader.h"
+#endif
+
 #define CONF_LOADED_EXTENSIONS	"/apps/epiphany/general/active_extensions"
 #define SCHEMA_FILE		"/epiphany-extension.xsd"
 
@@ -754,6 +758,21 @@ get_loader_for_type (EphyExtensionsManager *manager,
 
 		return g_object_ref (info->loader);
 	}
+	if (strcmp (type, "python") == 0)
+	{
+#ifdef ENABLE_PYTHON
+		info = g_new (LoaderInfo, 1);
+		info->type = g_strdup (type);
+		info->loader = g_object_new (EPHY_TYPE_PYTHON_LOADER, NULL);
+
+		manager->priv->factories =
+				g_list_append (manager->priv->factories, info);
+
+		return g_object_ref (info->loader);
+#else
+		return NULL;
+#endif
+	}
 
 	stype = sanitise_type (type);
 	name = g_strconcat ("lib", stype, "loader.", G_MODULE_SUFFIX, NULL);
@@ -821,7 +840,7 @@ load_extension (EphyExtensionsManager *manager,
 	loader = get_loader_for_type (manager, info->loader_type);
 	if (loader == NULL)
 	{
-		g_warning ("No loader found for extension '%s' of type '%s'\n",
+		g_message ("No loader found for extension '%s' of type '%s'\n",
 			   info->info.identifier, info->loader_type);
 		return;
 	}
@@ -872,6 +891,14 @@ detach_window (EphyWindow *window,
 	ephy_extension_detach_window (extension, window);
 }
 
+static gboolean
+idle_unref (GObject *object)
+{
+	g_object_unref (object);
+
+	return FALSE;
+}
+
 static void
 unload_extension (EphyExtensionsManager *manager,
 		  ExtensionInfo *info)
@@ -898,7 +925,7 @@ unload_extension (EphyExtensionsManager *manager,
 		 * extension has its own functions queued in the idle loop, the
 		 * functions must exist in memory before being called.
 		 */
-		ephy_object_idle_unref (info->extension);
+		g_idle_add ((GSourceFunc) idle_unref, info->extension);
 	}
 
 	ephy_loader_release_object (info->loader, G_OBJECT (info->extension));
