@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-main.c,v 1.37 2005/02/28 22:07:57 chpe Exp $
+ *  $Id: ephy-main.c,v 1.39 2005/05/11 11:30:37 chpe Exp $
  */
 
 #include "config.h"
@@ -47,9 +47,9 @@ static gboolean open_in_new_tab = FALSE;
 static gboolean open_fullscreen = FALSE;
 static gboolean open_as_bookmarks_editor = FALSE;
 
-static const char *session_filename = NULL;
-static const char *bookmark_url = NULL;
-static const char *bookmarks_file = NULL;
+static char *session_filename = NULL;
+static char *bookmark_url = NULL;
+static char *bookmarks_file = NULL;
 
 static struct poptOption popt_options[] =
 {
@@ -223,7 +223,7 @@ main (int argc, char *argv[])
 	program = gnome_program_init (PACKAGE, VERSION,
                                       LIBGNOMEUI_MODULE, argc, argv,
                                       GNOME_PARAM_POPT_TABLE, popt_options,
-                                      GNOME_PARAM_HUMAN_READABLE_NAME, _("Ephy"),
+                                      GNOME_PARAM_HUMAN_READABLE_NAME, _("Epiphany Web Browser"),
 				      GNOME_PARAM_APP_DATADIR, DATADIR,
                                       NULL);
 
